#! /usr/bin/env perl6

use v6.c;

use Test;

plan 1;

note "This module tests the actual program that is being installed. As a
result, it will run perl6 for every test case. This makes testing of this
module very slow. Please be patient.";

ok True;
